@@ -6,10 +6,10 @@
 
     This module is used to test mscolab related gui.
 
-    This file is part of mss.
+    This file is part of MSS.
 
     :copyright: Copyright 2019 Shivashis Padhi
-    :copyright: Copyright 2019-2022 by the mss team, see AUTHORS.
+    :copyright: Copyright 2019-2022 by the MSS team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -38,11 +38,11 @@ from mslib.mscolab.models import Permission, User
 from mslib.msui.flighttrack import WaypointsTableModel
 from PyQt5 import QtCore, QtTest, QtWidgets
 from mslib.utils.config import read_config_file, config_loader
-from mslib._tests.utils import mscolab_start_server, create_mss_settings_file, ExceptionMock
-import mslib.msui.mss_pyui as mss_pyui
+from mslib._tests.utils import mscolab_start_server, create_msui_settings_file, ExceptionMock
+from mslib.msui import msui
 from mslib.msui import mscolab
 from mslib.mscolab.mscolab import handle_db_reset
-from mslib._tests.constants import MSS_CONFIG_PATH
+from mslib._tests.constants import MSUI_CONFIG_PATH
 from mslib.mscolab.seed import add_user, get_user, add_operation, add_user_to_operation
 
 PORTS = list(range(25000, 25500))
@@ -62,7 +62,7 @@ class Test_Mscolab_connect_window():
 
         QtTest.QTest.qWait(500)
         self.application = QtWidgets.QApplication(sys.argv)
-        self.main_window = mss_pyui.MSSMainWindow(mscolab_data_dir=mscolab_settings.MSCOLAB_DATA_DIR)
+        self.main_window = msui.MSUIMainWindow(mscolab_data_dir=mscolab_settings.MSCOLAB_DATA_DIR)
         self.main_window.show()
         self.window = mscolab.MSColab_ConnectDialog(parent=self.main_window, mscolab=self.main_window.mscolab)
         self.window.urlCb.setEditText(self.url)
@@ -150,7 +150,7 @@ class Test_Mscolab_connect_window():
 
     @mock.patch("PyQt5.QtWidgets.QMessageBox.question", return_value=QtWidgets.QMessageBox.No)
     def test_add_users_without_updating_credentials_in_config_file(self, mockmessage):
-        create_mss_settings_file('{"MSCOLAB_mailid": "something@something.org", "MSCOLAB_password": "something"}')
+        create_msui_settings_file('{"MSCOLAB_mailid": "something@something.org", "MSCOLAB_password": "something"}')
         read_config_file()
         # check current settings
         assert config_loader(dataset="MSCOLAB_mailid") == "something@something.org"
@@ -166,7 +166,7 @@ class Test_Mscolab_connect_window():
 
     @mock.patch("PyQt5.QtWidgets.QMessageBox.question", return_value=QtWidgets.QMessageBox.Yes)
     def test_add_users_with_updating_credentials_in_config_file(self, mockmessage):
-        create_mss_settings_file('{"MSCOLAB_mailid": "something@something.org", "MSCOLAB_password": "something"}')
+        create_msui_settings_file('{"MSCOLAB_mailid": "something@something.org", "MSCOLAB_password": "something"}')
         read_config_file()
         # check current settings
         assert config_loader(dataset="MSCOLAB_mailid") == "something@something.org"
@@ -241,8 +241,8 @@ class Test_Mscolab_connect_window():
         QtWidgets.QApplication.processEvents()
 
     def _reset_config_file(self):
-        create_mss_settings_file('{ }')
-        config_file = fs.path.combine(MSS_CONFIG_PATH, "mss_settings.json")
+        create_msui_settings_file('{ }')
+        config_file = fs.path.combine(MSUI_CONFIG_PATH, "msui_settings.json")
         read_config_file(path=config_file)
 
 
@@ -270,9 +270,19 @@ class Test_Mscolab(object):
         assert add_user_to_operation(path=self.operation_name, emailid=self.userdata[0])
         self.user = get_user(self.userdata[0])
 
+        self.userdata2 = 'sree@sree.org', 'sree', 'sree'
+        self.operation_name3 = "kerala"
+        assert add_user(self.userdata2[0], self.userdata2[1], self.userdata2[2])
+        assert add_operation(self.operation_name3, "test kerala")
+        assert add_user_to_operation(path=self.operation_name3, emailid=self.userdata2[0])
+
+        self.userdata3 = 'anand@anand.org', 'anand', 'anand'
+        assert add_user(self.userdata3[0], self.userdata3[1], self.userdata3[2])
+        assert add_user_to_operation(path=self.operation_name3, access_level="collaborator", emailid=self.userdata3[0])
+
         QtTest.QTest.qWait(500)
         self.application = QtWidgets.QApplication(sys.argv)
-        self.window = mss_pyui.MSSMainWindow(mscolab_data_dir=mscolab_settings.MSCOLAB_DATA_DIR)
+        self.window = msui.MSUIMainWindow(mscolab_data_dir=mscolab_settings.MSCOLAB_DATA_DIR)
         self.window.show()
 
     def teardown(self):
@@ -350,9 +360,9 @@ class Test_Mscolab(object):
     @mock.patch("PyQt5.QtWidgets.QMessageBox")
     def test_import_file(self, mockbox, ext):
         self.window.remove_plugins()
-        with mock.patch("mslib.msui.mss_pyui.config_loader", return_value=self.import_plugins):
+        with mock.patch("mslib.msui.msui.config_loader", return_value=self.import_plugins):
             self.window.add_import_plugins("qt")
-        with mock.patch("mslib.msui.mss_pyui.config_loader", return_value=self.export_plugins):
+        with mock.patch("mslib.msui.msui.config_loader", return_value=self.export_plugins):
             self.window.add_export_plugins("qt")
         file_path = fs.path.join(mscolab_settings.MSCOLAB_DATA_DIR, f'test_import{ext}')
         with mock.patch("PyQt5.QtWidgets.QFileDialog.getSaveFileName", return_value=(file_path, None)):
@@ -482,6 +492,35 @@ class Test_Mscolab(object):
         assert os.path.isdir(os.path.join(mscolab_settings.MSCOLAB_DATA_DIR, operation_name)) is False
         assert mockbox.call_count == 1
 
+    @mock.patch("PyQt5.QtWidgets.QMessageBox.question", return_value=QtWidgets.QMessageBox.Yes)
+    def test_handle_leave_operation(self, mockmessage):
+        self._connect_to_mscolab()
+
+        self._login(self.userdata3[0], self.userdata3[2])
+        QtWidgets.QApplication.processEvents()
+        assert self.window.usernameLabel.text() == self.userdata3[1]
+        assert self.window.connectBtn.isVisible() is False
+
+        assert self.window.listOperationsMSC.model().rowCount() == 1
+        assert self.window.mscolab.active_op_id is None
+        self._activate_operation_at_index(0)
+        op_id = self.window.mscolab.get_recent_op_id()
+        assert op_id is not None
+
+        self.window.actionTopView.trigger()
+        QtWidgets.QApplication.processEvents()
+        assert len(self.window.get_active_views()) == 1
+        self.window.actionSideView.trigger()
+        QtWidgets.QApplication.processEvents()
+        assert len(self.window.get_active_views()) == 2
+
+        self.window.actionLeaveOperation.trigger()
+        QtWidgets.QApplication.processEvents()
+        QtTest.QTest.qWait(0)
+        assert self.window.mscolab.active_op_id is None
+        assert self.window.listViews.count() == 0
+        assert self.window.listOperationsMSC.model().rowCount() == 0
+
     def test_get_recent_op_id(self):
         self._connect_to_mscolab()
         self._create_user("anton", "anton@something.org", "something")
@@ -611,8 +650,8 @@ class Test_Mscolab(object):
         QtWidgets.QApplication.processEvents()
 
     def _reset_config_file(self):
-        create_mss_settings_file('{ }')
-        config_file = fs.path.combine(MSS_CONFIG_PATH, "mss_settings.json")
+        create_msui_settings_file('{ }')
+        config_file = fs.path.combine(MSUI_CONFIG_PATH, "msui_settings.json")
         read_config_file(path=config_file)
 
     @mock.patch("mslib.msui.mscolab.QtWidgets.QErrorMessage.showMessage")
