@@ -6,9 +6,10 @@
 
     Mscolab operation window, to display chat, file change
 
-    This file is part of mss.
+    This file is part of MSS.
 
     :copyright: 2019 Shivashis Padhi
+    :copyright: Copyright 2019-2022 by the MSS team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -34,7 +35,7 @@ from werkzeug.urls import url_join
 
 from mslib.mscolab.models import MessageType
 from PyQt5 import QtCore, QtGui, QtWidgets
-from mslib.msui.mss_qt import get_open_filename, get_save_filename, show_popup
+from mslib.utils.qt import get_open_filename, get_save_filename, show_popup
 from mslib.msui.qt5 import ui_mscolab_operation_window as ui
 from mslib.utils.config import config_loader
 
@@ -468,7 +469,11 @@ class MessageItem(QtWidgets.QWidget):
     def setup_image_message_box(self):
         MAX_WIDTH = MAX_HEIGHT = 300
         self.messageBox = QtWidgets.QLabel()
-        img_url = url_join(self.chat_window.mscolab_server_url, self.attachment_path)
+        if '\\' in self.attachment_path:
+            img_url = url_join(self.chat_window.mscolab_server_url,
+                               self.attachment_path.replace('\\', '/').split('colabdata')[1])
+        else:
+            img_url = url_join(self.chat_window.mscolab_server_url, self.attachment_path)
         data = requests.get(img_url).content
         image = QtGui.QImage()
         image.loadFromData(data)
