@@ -7,10 +7,10 @@
     Mscolab change history window to display the change history of the flight path so that users
     can revert back to a previous version
 
-    This file is part of mss.
+    This file is part of MSS.
 
     :copyright: 2020 Tanish Grover
-    :copyright: Copyright 2020-2022 by the mss team, see AUTHORS.
+    :copyright: Copyright 2020-2022 by the MSS team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -35,7 +35,7 @@ from mslib.utils.verify_user_token import verify_user_token
 from mslib.msui.flighttrack import WaypointsTableModel
 from PyQt5 import QtCore, QtWidgets, QtGui
 from mslib.msui.qt5 import ui_mscolab_version_history as ui
-from mslib.msui.mss_qt import show_popup
+from mslib.utils.qt import show_popup
 from mslib.utils.config import config_loader
 from mslib.utils.time import utc_to_local_datetime
 
